@@ -24,24 +24,44 @@ use vars qw(%PRIORITY %LEVELS);
 our %PRIORITY = (); # unless (%PRIORITY);
 our %LEVELS = () unless (%LEVELS);
 our %SYSLOG = () unless (%SYSLOG);
+our %L4P_TO_LD = () unless (%L4P_TO_LD);
 
 sub add_priority {
-  my ($prio, $intval, $syslog) = @_;
+  my ($prio, $intval, $syslog, $log_dispatch_level) = @_;
   $prio = uc($prio); # just in case;
 
-  $PRIORITY{$prio} = $intval;
-  $LEVELS{$intval} = $prio;
-  $SYSLOG{$prio} = $syslog if defined($syslog);
+  $PRIORITY{$prio}    = $intval;
+  $LEVELS{$intval}    = $prio;
+
+  # Set up the mapping between Log4perl integer levels and 
+  # Log::Dispatch levels
+  # Note: Log::Dispatch uses the following levels:
+  # 0 debug
+  # 1 info
+  # 2 notice
+  # 3 warning
+  # 4 error
+  # 5 critical
+  # 6 alert
+  # 7 emergency
+
+      # The equivalent Log::Dispatch level is optional, set it to 
+      # the highest value (7=emerg) if it's not provided.
+  $log_dispatch_level = 7 unless defined $log_dispatch_level;
+  
+  $L4P_TO_LD{$prio}  = $log_dispatch_level;
+
+  $SYSLOG{$prio}      = $syslog if defined($syslog);
 }
 
 # create the basic priorities
-add_priority("OFF",   OFF_INT,   -1);
-add_priority("FATAL", FATAL_INT, 0);
-add_priority("ERROR", ERROR_INT, 3);
-add_priority("WARN",  WARN_INT,  4);
-add_priority("INFO",  INFO_INT,  6);
-add_priority("DEBUG", DEBUG_INT, 7);
-add_priority("ALL",   ALL_INT,   7);
+add_priority("OFF",   OFF_INT,   -1, 7);
+add_priority("FATAL", FATAL_INT,  0, 7);
+add_priority("ERROR", ERROR_INT,  3, 4);
+add_priority("WARN",  WARN_INT,   4, 3);
+add_priority("INFO",  INFO_INT,   6, 1);
+add_priority("DEBUG", DEBUG_INT,  7, 0);
+add_priority("ALL",   ALL_INT,    7, 0);
 
 # we often sort numerically, so a helper func for readability
 sub numerically {$a <=> $b}
@@ -210,21 +230,19 @@ Log::Log4perl::Level - Predefined log levels
 
 =head1 SYNOPSIS
 
-  use Log::Log4perl;
+  use Log::Log4perl::Level;
+  print $ERROR, "\n";
 
+  # -- or --
+
+  use Log::Log4perl qw(:levels);
   print $ERROR, "\n";
 
 =head1 DESCRIPTION
 
-The C<Log::Log4perl::Level> package is included if you say
-
-    use Log::Log4perl;
-
-so there's usually no need to call it explicitely.
-It simply exports a predefined set of I<Log4perl> log
+C<Log::Log4perl::Level> simply exports a predefined set of I<Log4perl> log
 levels into the caller's name space. It is used internally by 
-C<Log::Log4perl>. The following scalars are defined in the 
-caller's namespace:
+C<Log::Log4perl>. The following scalars are defined:
 
     $OFF
     $FATAL
@@ -234,6 +252,14 @@ caller's namespace:
     $DEBUG
     $ALL
 
+C<Log::Log4perl> also exports these constants into the caller's namespace
+if you pull it in providing the C<:levels> tag:
+
+    use Log::Log4perl qw(:levels);
+
+This is the preferred way, there's usually no need to call 
+C<Log::Log4perl::Level> explicitely.
+
 The numerical values assigned to these constants are purely virtual,
 only used by Log::Log4perl internally and can change at any time,
 so please don't make any assumptions.
@@ -241,10 +267,10 @@ so please don't make any assumptions.
 If the caller wants to import these constants into a different namespace,
 it can be provided with the C<use> command:
 
-    use Log::Log4perl::Level qw(Level);
+    use Log::Log4perl::Level qw(MyNameSpace);
 
-After this C<$Level::ERROR>, C<$Level::INFO> etc. will be defined
-accordingly.
+After this C<$MyNameSpace::ERROR>, C<$MyNameSpace::INFO> etc. 
+will be defined accordingly.
 
 =head1 SEE ALSO
 
